@@ -89,10 +89,10 @@ setMethod(
     ## Resetting all factors that need to be set. 
     slot(x, "tab")       <- res
     slot(x, "loc.fac")   <- factor(locnames, names(allnames))
-    # slot(x, "loc.names") <- names(allnames)
-    slot(x, "loc.n.all")  <- locnall
+    slot(x, "loc.n.all") <- locnall
     slot(x, "all.names") <- allnames
-    slot(x, "alllist")   <- .Call("expand_indices", cumsum(locnall), length(j), PACKAGE = "poppr")
+    slot(x, "alllist")   <- .Call("expand_indices", cumsum(locnall), 
+                                  length(j), PACKAGE = "poppr")
     slot(x, "names")     <- slot(x, "names")[i]
     return(x)
   }
@@ -161,7 +161,8 @@ setMethod(
     slot(.Object, "loc.fac")   <- slot(gen, "loc.fac")
     slot(.Object, "loc.n.all") <- num_alleles  
     slot(.Object, "all.names") <- slot(gen, "all.names") 
-    slot(.Object, "alllist")   <- .Call("expand_indices", cumsum(num_alleles), num_loci, PACKAGE = "poppr")
+    slot(.Object, "alllist")   <- .Call("expand_indices", cumsum(num_alleles), 
+                                        num_loci, PACKAGE = "poppr")
     slot(.Object, "names")     <- objnames
     slot(.Object, "type")      <- slot(gen, "type")
     slot(.Object, "ploidy")    <- as.integer(slot(gen, "ploidy"))
@@ -349,31 +350,28 @@ setMethod(
   f = "show", 
   signature("snpclone"),
   definition = function(object){
-    callNextMethod()
-    cat(" // snpclone contents ---\n")
-#     if (length(object@hierarchy) > 0){
-#       hiernames <- names(object@hierarchy)
-#       hierlen <- length(hiernames)
-#       nameshow <- ifelse(hierlen > 6, 
-#                          c(utils::head(hiernames, 3), "...", utils::tail(hiernames, 3)), 
-#                          hiernames)
-#       nameshow <- paste(nameshow, collapse = ", ")
-#       cat(" @hierarchy:", "a data frame with", hierlen, 
-#           "levels: (", nameshow, ")\n")
-#     }
+    y <- utils::capture.output(callNextMethod())
+    y <- gsub("GENLIGHT", "SNPCLONE", y)
+    y <- gsub("/", "|", y)
+    genspot <- grepl("@gen", y)
+    
     the_type <- visible(object@mlg)
     mlgtype  <- ifelse(is(object@mlg, "MLG"), paste0(the_type, " "), "")
     mlgtype  <- paste0(mlgtype, "multilocus genotypes")
-    cat("   @mlg:", length(unique(object@mlg[])), mlgtype)
+
+    msg <- paste("   @mlg:", length(unique(object@mlg[])), mlgtype)
     if (the_type == "contracted"){
       thresh <- round(cutoff(object@mlg)["contracted"], 3)
       algo <- strsplit(distalgo(object@mlg), "_")[[1]][1]
       dist <- distname(object@mlg)
       if (!is.character(dist)){
-        dist <- paste(utils::capture.output(dist), collapse = "")        
+        dist <- paste0(utils::capture.output(dist), collapse = "")
       }
-      cat(" (", thresh, ") [t], (", dist, ") [d], (", algo, ") [a]", sep = "")
+      msg <- paste0(msg, "\n         ",
+                    "(", thresh, ") [t], (", dist, ") [d], (", algo, ") [a]")
     }
+    y[genspot] <- paste(y[genspot], msg, sep = "\n")
+    cat(y, sep = "\n")
   }
 )
 
@@ -539,7 +537,7 @@ setMethod(
       
     } else {
       if (class(x@mlg)[1] != "MLG"){
-        x@mlg <- mlg.vector(x, reset = TRUE)        
+        x@mlg <- mlg.vector(x, reset = TRUE)
       } else {
         x@mlg <- new("MLG", mlg.vector(x, reset = TRUE))
       }
@@ -565,7 +563,7 @@ setMethod(
       sep    <- ifelse(length(ploid) > 2, ", ", " ")
       ploid  <- paste0(ploid1, sep, "and ", ploid[length(ploid)])
     }
-    nind    <- nInd(object)     
+    nind    <- nInd(object)
     type    <- ifelse(object@type == "PA", "dominant", "codominant")
     nmlg    <- length(unique(object@mlg))
     nloc    <- nLoc(object)
@@ -584,11 +582,12 @@ setMethod(
       dist <- distname(object@mlg)
       algo <- strsplit(distalgo(object@mlg), "_")[[1]][1]
       if (!is.character(dist)){
-        dist <- paste(utils::capture.output(dist), collapse = "")        
+        dist <- paste(utils::capture.output(dist), collapse = "")
       }
       contab <- max(chars)
       contab <- substr("             ", 1, contab + 4)
-      mlgthresh <- paste0("\n", contab, "(", thresh, ") [t], (", dist, ") [d], (", algo, ") [a]")
+      mlgthresh <- paste0("\n", contab, 
+                          "(", thresh, ") [t], (", dist, ") [d], (", algo, ") [a]")
       mlgtype  <- paste0(mlgtype, mlgthresh)
     }
     if (poplen > 7) 
@@ -604,14 +603,14 @@ setMethod(
       ltab[2], nind, ploid, "individuals\n", 
       ltab[3], nloc, type, "loci\n\n"
       )
-    popstrata <- ifelse(strata > 1, "strata -", "stratification -")
+    popstrata <- ifelse(strata > 1, "strata -", "stratum -")
     if (strata == 0) popstrata <- "strata."
     popdef  <- ifelse(npop > 0, "defined -", "defined.")
     cat("Population information:\n\n")
     cat("", ltab[4], strata, popstrata, stratanames, fill = TRUE)
     if (!is.null(object@hierarchy)){
-      cat("", ltab[5], "1", "hierarchy -", paste(object@hierarchy, collapse = ""), 
-          fill = TRUE)
+      cat("", ltab[5], "1", "hierarchy -", 
+          paste(object@hierarchy, collapse = ""), fill = TRUE)
     }
     cat("", ltab[6], npop, "populations", popdef, pops, fill = TRUE)
     
@@ -659,18 +658,19 @@ setMethod(
       dist <- distname(x@mlg)
       algo <- strsplit(distalgo(x@mlg), "_")[[1]][1]
       if (!is.character(dist)){
-        dist <- paste(utils::capture.output(dist), collapse = "")        
+        dist <- paste(utils::capture.output(dist), collapse = "")
       }
       contab <- max(chars)
       contab <- substr("             ", 1, contab + 4)
-      mlgthresh <- paste0("\n", contab, "(", thresh, ") [t], (", dist, ") [d], (", algo, ") [a]")
+      mlgthresh <- paste0("\n", contab, 
+                          "(", thresh, ") [t], (", dist, ") [d], (", algo, ") [a]")
       mlgtype  <- paste0(mlgtype, mlgthresh)
     }
     if (!fullnames){
       poplen <- length(pops)
       stratalen <- length(stratanames)
       if (poplen > 7){
-        pops <- c(pops[1:3], "...", pops[(poplen-2):poplen])        
+        pops <- c(pops[1:3], "...", pops[(poplen-2):poplen])
       }
       if (stratalen > 7){
         stratanames <- c(stratanames[1:3], "...", stratanames[(stratalen-2):stratalen])
@@ -683,7 +683,7 @@ setMethod(
       ltab[2], nind, ploid, "individuals\n", 
       ltab[3], nloc, type, "loci\n\n",
       fill = TRUE)
-    popstrata <- ifelse(strata > 1, "strata -", "stratification -")
+    popstrata <- ifelse(strata > 1, "strata -", "stratum -")
     if (strata == 0) popstrata <- "strata."
     popdef  <- ifelse(npop > 0, "defined -", "defined.")
     cat("Population information:\n\n")
@@ -819,7 +819,10 @@ setMethod(
 #'   - user-defined MLGs }
 #'   
 #' @rdname mll-method
-#' @aliases mll,genclone-method mll,snpclone-method mll,genind-method
+#' @aliases mll,genclone-method 
+#'   mll,snpclone-method 
+#'   mll,genind-method
+#'   mll,genlight-method
 #' @docType methods
 #' @author Zhian N. Kamvar
 #' @seealso \code{\link{mll.custom}} \code{\link{mlg.table}}
@@ -838,38 +841,18 @@ mll <- function(x, type = NULL) standardGeneric("mll")
 #' @export
 setGeneric("mll")
 
-mll.internal <- function(x, type = NULL, the_call = match.call()){
-  mlg <- x@mlg
-  if (!"MLG" %in% class(mlg)){
-    the_obj <- as.character(the_call[["x"]])
-    the_type <- as.character(the_call[["type"]])
-    if (length(the_type) == 0) the_type <- "original"
-    msg <- paste("\n The @mlg slot does not contain an MLG class object.\n",
-                 "Returning the original mlgs. Please use:\n\n",
-                 paste0('mll(', the_obj, ') <- "', the_type, '"\n'),
-                 "\n to convert your object.")
-    warning(msg, call. = FALSE)
-    return(mlg)
-  }
-  if (!is.null(type)){
-    TYPES <- c("original", "expanded", "contracted", "custom")
-    type <- match.arg(type, TYPES)
-  } else {
-    type <-visible(mlg)
-  }
-  return(mlg[, type])
-}
-
 setMethod(
   f = "mll",
   signature(x = "genind"),
   definition = function(x, type = NULL){
-    if (!is.null(type)){
-      msg <- paste("The object you are using is a genind object and does not",
-                   "contain an mlg slot. Returning the results of mlg.vector().")
-      warning(msg)
-    }
-    mlg.vector(x)
+    mll.gen.internal(x, type)
+  })
+
+setMethod(
+  f = "mll",
+  signature(x = "genlight"),
+  definition = function(x, type = NULL){
+    mll.gen.internal(x, type)
   })
 
 setMethod(
@@ -886,27 +869,13 @@ setMethod(
     mll.internal(x, type, match.call())
   })
 
-setMethod(
-  f = "mll",
-  signature(x = "snpclone"),
-  definition = function(x, type = NULL){
-    mlg <- x@mlg
-    if (!"MLG" %in% class(mlg)){
-      return(mlg)
-    }
-    if (!is.null(type)){
-      TYPES <- c("original", "expanded", "contracted", "custom")
-      type <- match.arg(type, TYPES)
-    } else {
-      type <-visible(mlg)
-    }
-    return(mlg[, type])
-  })
-
 #==============================================================================#
 #' @export
 #' @rdname mll-method
-#' @aliases nmll,genclone-method nmll,snpclone-method
+#' @aliases nmll,genclone-method 
+#'   nmll,snpclone-method 
+#'   nmll,genind-method
+#'   nmll,genlight-method
 #' @docType methods
 #==============================================================================#
 nmll <- function(x, type = NULL) standardGeneric("nmll")
@@ -928,10 +897,25 @@ setMethod(
     length(unique(mll(x, type)))
   })
 
+setMethod(
+  f = "nmll",
+  signature(x = "genind"),
+  definition = function(x, type = NULL){
+    mlg(x, quiet = TRUE)
+  })
+
+setMethod(
+  f = "nmll",
+  signature(x = "genlight"),
+  definition = function(x, type = NULL){
+    mlg(x, quiet = TRUE)
+  })
+
 #==============================================================================#
 #' @export
 #' @rdname mll-method
-#' @aliases mll<-,genclone-method mll<-,snpclone-method
+#' @aliases mll<-,genclone-method 
+#'   mll<-,snpclone-method
 #' @docType methods
 #==============================================================================#
 "mll<-" <- function(x, value) standardGeneric("mll<-")
@@ -980,7 +964,8 @@ setMethod(
 #'   the MLGs.
 #' @return an object of the same type as x
 #' @rdname mll.reset-method
-#' @aliases mll.reset,genclone-method mll.reset,snpclone-method
+#' @aliases mll.reset,genclone-method 
+#'   mll.reset,snpclone-method
 #' @docType methods
 #' @author Zhian N. Kamvar
 #' @seealso \code{\link{mll}} \code{\link{mlg.table}} \code{\link{mll.custom}}
@@ -1055,7 +1040,8 @@ setMethod(
 #' 
 #' @return an object of the same type as x
 #' @rdname mll.custom
-#' @aliases mll.custom,genclone-method mll.custom,snpclone-method
+#' @aliases mll.custom,genclone-method 
+#'   mll.custom,snpclone-method
 #' @docType methods
 #' @author Zhian N. Kamvar
 #' @seealso \code{\link{mll}} \code{\link{mlg.table}}
@@ -1095,7 +1081,8 @@ setMethod(
 #==============================================================================#
 #' @export
 #' @rdname mll.custom
-#' @aliases mll.custom<-,genclone-method mll.custom<-,snpclone-method
+#' @aliases mll.custom<-,genclone-method 
+#'   mll.custom<-,snpclone-method
 #' @docType methods
 #==============================================================================#
 "mll.custom<-" <- function(x, set = TRUE, value) standardGeneric("mll.custom<-")
@@ -1120,7 +1107,8 @@ setMethod(
 #==============================================================================#
 #' @export
 #' @rdname mll.custom
-#' @aliases mll.levels,genclone-method mll.levels,snpclone-method
+#' @aliases mll.levels,genclone-method 
+#'   mll.levels,snpclone-method
 #' @docType methods
 #==============================================================================#
 mll.levels <- function(x, set = TRUE, value) standardGeneric("mll.levels")
@@ -1148,7 +1136,8 @@ setMethod(
 #==============================================================================#
 #' @export
 #' @rdname mll.custom
-#' @aliases mll.levels<-,genclone-method mll.levels<-,snpclone-method
+#' @aliases mll.levels<-,genclone-method 
+#'   mll.levels<-,snpclone-method
 #' @docType methods
 #==============================================================================#
 "mll.levels<-" <- function(x, set = TRUE, value) standardGeneric("mll.levels<-")
@@ -1177,8 +1166,8 @@ setMethod(
 #' 
 #' Create a vector of multilocus genotype indices filtered by minimum distance.
 #'   
-#' @param pop a \code{\linkS4class{genind}} or \code{\linkS4class{genclone}} 
-#'   object.
+#' @param pop a \code{\linkS4class{genclone}}, \code{\linkS4class{snpclone}}, or
+#'   \code{\linkS4class{genind}} object.
 #' @param threshold the desired minimum distance between distinct genotypes. 
 #'   Defaults to 0, which will only merge identical genotypes
 #' @param missing any method to be used by \code{\link{missingno}}: "mean", 
@@ -1195,10 +1184,10 @@ setMethod(
 #'   "average_neighbor" merges clusters based on the average distance between 
 #'   every pair of points between clusters.
 #' @param distance a character or function defining the distance to be applied 
-#'   to pop. Defaults to \code{\link{nei.dist}} for genclone objects and
+#'   to pop. Defaults to \code{\link{diss.dist}} for genclone objects and
 #'   \code{\link{bitwise.dist}} for snpclone objects. A matrix or table
 #'   containing distances between individuals (such as the output of 
-#'   \code{\link{nei.dist}}) is also accepted for this parameter.
+#'   \code{\link{rogers.dist}}) is also accepted for this parameter.
 #' @param threads The maximum number of parallel threads to be used within this 
 #'   function. A value of 0 (default) will attempt to use as many threads as 
 #'   there are available cores/CPUs. In most cases this is ideal. A value of 1 
@@ -1248,11 +1237,19 @@ setMethod(
 #'   \code{mlg.vector}) in in each new multilocus genotype. Therefore
 #'   \code{mlg.vector} and \code{mlg.vector} return the same vector when
 #'   threshold is set to 0 or less.
-#' 
+#' @seealso \code{\link{filter_stats}} 
+#'   \code{\link{cutoff_predictor}} 
+#'   \code{\link{mll}}
+#'   \code{\link{genclone}}
+#'   \code{\link{snpclone}}
+#'   \code{\link{diss.dist}}
+#'   \code{\link{bruvo.dist}}
 #' @export
 #' @rdname mlg.filter
-#' @aliases mlg.filter,genclone-method mlg.filter,snpclone-method 
-#'   mlg.filter,genind-method mlg.filter,genlight-method
+#' @aliases mlg.filter,genclone-method 
+#'   mlg.filter,snpclone-method 
+#'   mlg.filter,genind-method 
+#'   mlg.filter,genlight-method
 #' @docType methods
 #' @examples 
 #' data(partial_clone)
@@ -1293,7 +1290,7 @@ setMethod(
 #==============================================================================#
 mlg.filter <- function(pop, threshold=0.0, missing="asis", memory=FALSE, 
                        algorithm="farthest_neighbor", 
-                       distance="nei.dist", threads=0, stats="MLGs", ...){
+                       distance="diss.dist", threads=0, stats="MLGs", ...){
   standardGeneric("mlg.filter")
 }
 
@@ -1304,7 +1301,7 @@ setMethod(
   f = "mlg.filter",
   signature(pop = "genind"),
   definition = function(pop, threshold=0.0, missing="asis", memory=FALSE,
-                        algorithm="farthest_neighbor", distance="nei.dist", 
+                        algorithm="farthest_neighbor", distance="diss.dist", 
                         threads=0, stats="MLGs", ...){
     the_call <- match.call()
     mlg.filter.internal(pop, threshold, missing, memory, algorithm, distance,
@@ -1316,7 +1313,7 @@ setMethod(
   f = "mlg.filter",
   signature(pop = "genlight"),
   definition = function(pop, threshold=0.0, missing="asis", memory=FALSE,
-                        algorithm="farthest_neighbor", distance="nei.dist", 
+                        algorithm="farthest_neighbor", distance="bitwise.dist", 
                         threads=0, stats="MLGs", ...){
     the_call <- match.call()
     mlg.filter.internal(pop, threshold, missing, memory, algorithm, distance,
@@ -1328,7 +1325,7 @@ setMethod(
   f = "mlg.filter",
   signature(pop = "genclone"),
   definition = function(pop, threshold=0.0, missing="asis", memory=FALSE,
-                        algorithm="farthest_neighbor", distance="nei.dist", 
+                        algorithm="farthest_neighbor", distance="diss.dist", 
                         threads=0, stats="MLGs", ...){
     the_call <- match.call()
     mlg.filter.internal(pop, threshold, missing, memory, algorithm, distance,
@@ -1351,12 +1348,14 @@ setMethod(
 #' @export
 #' @rdname mlg.filter
 #' @param value the threshold at which genotypes should be collapsed.
-#' @aliases mlg.filter<-,genclone-method mlg.filter<-,genind-method 
-#'   mlg.filter<-,snpclone-method mlg.filter<-,genlight-method
+#' @aliases mlg.filter<-,genclone-method 
+#'   mlg.filter<-,genind-method 
+#'   mlg.filter<-,snpclone-method 
+#'   mlg.filter<-,genlight-method
 #' @docType methods
 #==============================================================================#
 "mlg.filter<-" <- function(pop, missing = "asis", memory = FALSE, 
-                           algorithm = "farthest_neighbor", distance = "nei.dist",
+                           algorithm = "farthest_neighbor", distance = "diss.dist",
                            threads = 0, ..., value){
   standardGeneric("mlg.filter<-")
 }
@@ -1369,7 +1368,7 @@ setMethod(
   f = "mlg.filter<-",
   signature(pop = "genind"),
   definition = function(pop, missing = "asis", memory = FALSE, 
-                        algorithm = "farthest_neighbor", distance = "nei.dist",
+                        algorithm = "farthest_neighbor", distance = "diss.dist",
                         threads = 0, ..., value){
     if (!is.genclone(pop)){
       the_warning <- paste("mlg.filter<- only has an effect on genclone",
@@ -1387,7 +1386,7 @@ setMethod(
   f = "mlg.filter<-",
   signature(pop = "genlight"),
   definition = function(pop, missing = "asis", memory = FALSE, 
-                        algorithm = "farthest_neighbor", distance = "nei.dist",
+                        algorithm = "farthest_neighbor", distance = "bitwise.dist",
                         threads = 0, ..., value){
     if (!is.snpclone(pop)){
       the_warning <- paste("mlg.filter<- only has an effect on snpclone",
@@ -1406,7 +1405,7 @@ setMethod(
   f = "mlg.filter<-",
   signature(pop = "genclone"),
   definition = function(pop, missing = "asis", memory = FALSE, 
-                       algorithm = "farthest_neighbor", distance = "nei.dist",
+                       algorithm = "farthest_neighbor", distance = "diss.dist",
                        threads = 0, ..., value){
     pop       <- callNextMethod()
     the_call  <- match.call()
